/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_1Gx7Y2HF);
  numBytes += sLine_init(&sLine_ZYCXxeBS);
  numBytes += sLine_init(&sLine_Mh7UIyif);
  numBytes += sLine_init(&sLine_zrZ8Zn9V);
  numBytes += sLine_init(&sLine_8FvoQI2x);
  numBytes += sBiquad_init(&sBiquad_s_KmPgclus);
  numBytes += sLine_init(&sLine_BNTXFjSi);
  numBytes += sLine_init(&sLine_tUFVb7Fh);
  numBytes += sLine_init(&sLine_M0Qx4cDN);
  numBytes += sLine_init(&sLine_ig5Dd3Oq);
  numBytes += sBiquad_init(&sBiquad_s_aBFRnTkX);
  numBytes += sLine_init(&sLine_B2RVniFC);
  numBytes += sLine_init(&sLine_UMedoi9s);
  numBytes += sLine_init(&sLine_UlGSEZ28);
  numBytes += sLine_init(&sLine_Zj57gEy9);
  numBytes += sLine_init(&sLine_qEEzkQ9W);
  numBytes += sBiquad_init(&sBiquad_s_XqXqdMxL);
  numBytes += sLine_init(&sLine_70jxgnyg);
  numBytes += sLine_init(&sLine_fMHKhqQY);
  numBytes += sLine_init(&sLine_o3j1ELj8);
  numBytes += sLine_init(&sLine_h0GpShuZ);
  numBytes += sLine_init(&sLine_T4A5wP6B);
  numBytes += sBiquad_init(&sBiquad_s_6oriTvMc);
  numBytes += sLine_init(&sLine_YkAO5F8i);
  numBytes += sLine_init(&sLine_8i2nqTKK);
  numBytes += sLine_init(&sLine_qEk3Po23);
  numBytes += sLine_init(&sLine_qjpZEpFl);
  numBytes += sBiquad_init(&sBiquad_s_NqkyL5lW);
  numBytes += sLine_init(&sLine_JU0cfcXC);
  numBytes += sLine_init(&sLine_zXwZug79);
  numBytes += sLine_init(&sLine_ubcys9bZ);
  numBytes += sLine_init(&sLine_hy2GDL01);
  numBytes += sLine_init(&sLine_F2Yy0nTJ);
  numBytes += sBiquad_init(&sBiquad_s_uUDmcPkg);
  numBytes += sLine_init(&sLine_mjv8jFQN);
  numBytes += sPhasor_k_init(&sPhasor_D1ootq5S, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_gwpRBOmu);
  numBytes += sRPole_init(&sRPole_LMkg5HzG);
  numBytes += sRPole_init(&sRPole_u6YuH2zn);
  numBytes += sTabhead_init(&sTabhead_qT2NwMo2, &hTable_1LHXwIKz);
  numBytes += sTabread_init(&sTabread_hNPzL4D0, &hTable_1LHXwIKz, false);
  numBytes += sTabread_init(&sTabread_UGuJWXUU, &hTable_1LHXwIKz, false);
  numBytes += sLine_init(&sLine_LUXc7hWl);
  numBytes += sTabhead_init(&sTabhead_Ra0D9seO, &hTable_btcsgDJs);
  numBytes += sTabread_init(&sTabread_YCfT3UuN, &hTable_btcsgDJs, false);
  numBytes += sTabread_init(&sTabread_o65nHdTh, &hTable_btcsgDJs, false);
  numBytes += sLine_init(&sLine_Z1PgpPDZ);
  numBytes += sTabwrite_init(&sTabwrite_ZPYbpKpP, &hTable_btcsgDJs);
  numBytes += sTabwrite_init(&sTabwrite_XZdFu1sM, &hTable_1LHXwIKz);
  numBytes += sLine_init(&sLine_vneUxki9);
  numBytes += sPhasor_k_init(&sPhasor_2LkW8BEZ, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_SImcAAti);
  numBytes += sRPole_init(&sRPole_NSjmtnqk);
  numBytes += sRPole_init(&sRPole_9HX7KN0d);
  numBytes += sTabhead_init(&sTabhead_kzXiEHwA, &hTable_SGyzbNGb);
  numBytes += sTabread_init(&sTabread_CE2HBtuj, &hTable_SGyzbNGb, false);
  numBytes += sTabread_init(&sTabread_PSCMOilS, &hTable_SGyzbNGb, false);
  numBytes += sLine_init(&sLine_NAJnELOo);
  numBytes += sTabhead_init(&sTabhead_Rz7lE6Dn, &hTable_SmkOSjb2);
  numBytes += sTabread_init(&sTabread_doxjHEXY, &hTable_SmkOSjb2, false);
  numBytes += sTabread_init(&sTabread_7hbxj1t6, &hTable_SmkOSjb2, false);
  numBytes += sLine_init(&sLine_x8S6eF0t);
  numBytes += sTabwrite_init(&sTabwrite_gxlhdBQz, &hTable_SmkOSjb2);
  numBytes += sTabwrite_init(&sTabwrite_e9ftxHM1, &hTable_SGyzbNGb);
  numBytes += sLine_init(&sLine_s9WROZuE);
  numBytes += sPhasor_k_init(&sPhasor_1XNwtBSY, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_3PYDq4Ni);
  numBytes += sRPole_init(&sRPole_ZrcrR4E5);
  numBytes += sRPole_init(&sRPole_oMmv15Hr);
  numBytes += sTabhead_init(&sTabhead_xFElLJUa, &hTable_mOUF5EB2);
  numBytes += sTabread_init(&sTabread_r6LDJnSj, &hTable_mOUF5EB2, false);
  numBytes += sTabread_init(&sTabread_USBpd2Pd, &hTable_mOUF5EB2, false);
  numBytes += sLine_init(&sLine_tNOclUr5);
  numBytes += sTabhead_init(&sTabhead_bgLE2dj0, &hTable_sU0MT3tE);
  numBytes += sTabread_init(&sTabread_qKE1QuFC, &hTable_sU0MT3tE, false);
  numBytes += sTabread_init(&sTabread_2u5S25OV, &hTable_sU0MT3tE, false);
  numBytes += sLine_init(&sLine_c1wcgcxq);
  numBytes += sTabwrite_init(&sTabwrite_aFSBJYhh, &hTable_sU0MT3tE);
  numBytes += sTabwrite_init(&sTabwrite_4YyZ2uvz, &hTable_mOUF5EB2);
  numBytes += cVar_init_f(&cVar_o8A9tmbz, 0.0f);
  numBytes += cVar_init_f(&cVar_x9z1Te0w, 0.0f);
  numBytes += cVar_init_f(&cVar_XqxJaFF0, 0.0f);
  numBytes += cVar_init_f(&cVar_HXUEig5A, 0.0f);
  numBytes += cSlice_init(&cSlice_jGrHh9kD, 1, -1);
  numBytes += cVar_init_f(&cVar_t8xCIRtH, 1337.0f);
  numBytes += cVar_init_f(&cVar_wNN29RX1, 0.0f);
  numBytes += cIf_init(&cIf_5RT9dVVM, false);
  numBytes += cIf_init(&cIf_FcH5wjrZ, false);
  numBytes += cBinop_init(&cBinop_eioLD2Hc, 0.0f); // __pow
  numBytes += cIf_init(&cIf_nT3O1Eub, false);
  numBytes += cBinop_init(&cBinop_KEYOPRo1, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_DK0JfwzC, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_b4D0E5tS, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_hYfdJxDv, 0.0f);
  numBytes += cIf_init(&cIf_9DxEjU8l, false);
  numBytes += cIf_init(&cIf_IaLbijYJ, false);
  numBytes += cBinop_init(&cBinop_oSjDlcFZ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_nGeaoHFx, false);
  numBytes += cBinop_init(&cBinop_Pv8qagIY, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_uZIOkf7G, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_FmRn6oUd, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ArzTSclC, 0.0f);
  numBytes += cIf_init(&cIf_wVpVb2Jy, false);
  numBytes += cIf_init(&cIf_DBGtGgkp, false);
  numBytes += cBinop_init(&cBinop_njhgRydX, 0.0f); // __pow
  numBytes += cIf_init(&cIf_yX7yapek, false);
  numBytes += cBinop_init(&cBinop_WJf40oip, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Iw4bl0L2, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_g0pJ88uS, -15.0f); // __eq
  numBytes += cIf_init(&cIf_fH6Ksvcp, false);
  numBytes += cSlice_init(&cSlice_5Sk6mgpL, 1, -1);
  numBytes += cVar_init_f(&cVar_ZZ0PPLjI, 0.0f);
  numBytes += cSlice_init(&cSlice_NTKtdRbB, 1, -1);
  numBytes += cVar_init_f(&cVar_Ldne6noG, 0.0f);
  numBytes += cSlice_init(&cSlice_f89j1p3M, 1, -1);
  numBytes += cVar_init_f(&cVar_yWd8Wncu, 0.0f);
  numBytes += cSlice_init(&cSlice_nmu5E0dr, 1, -1);
  numBytes += cVar_init_f(&cVar_fieuYC5z, 0.313f);
  numBytes += cBinop_init(&cBinop_gwX2yQxf, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_KG7twc9a, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_QCyDj6EP, 0.0f);
  numBytes += cVar_init_f(&cVar_pk1hMEiu, 1337.0f);
  numBytes += cVar_init_f(&cVar_CeeyKK6Z, 0.3f);
  numBytes += cBinop_init(&cBinop_Rf9ikTkF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FvDs0oBc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ScYHXUvh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_I652hys4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WUSWYwR7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_q6aLCPJG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PpRhCssl, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_2fxL7upP, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_bKkBXD23, 0.0f);
  numBytes += cVar_init_f(&cVar_nh9RBBpq, 1337.0f);
  numBytes += cVar_init_f(&cVar_vKxlPOVz, 0.313f);
  numBytes += cBinop_init(&cBinop_v8MEoQ7x, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_y8xrknEB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wO6nqpvv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lkux9z5e, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zLOZFuCS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_znYrjeXU, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_DXTQCRnE, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_MbLFGxnB, 0.0f);
  numBytes += cVar_init_f(&cVar_WxTn34EO, 1037.0f);
  numBytes += cVar_init_f(&cVar_MZ8OWomb, 0.4f);
  numBytes += cBinop_init(&cBinop_gSfj5WmF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yVdJEmcH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VsypA919, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zYPXQyyd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FIB2GR2D, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KsB9diWF, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_2yV6Qlef, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7s7XzUZ3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3E1bPcDT, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_ILcfPKvl, 1, -1);
  numBytes += cVar_init_f(&cVar_JUHR9hFS, 1337.0f);
  numBytes += cVar_init_f(&cVar_7MsDGqAr, 0.0f);
  numBytes += cIf_init(&cIf_vMztCwGj, false);
  numBytes += cIf_init(&cIf_jF6StMHi, false);
  numBytes += cBinop_init(&cBinop_uBVTUlXJ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_PPPBo8Bt, false);
  numBytes += cBinop_init(&cBinop_Usc4HXAW, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_eUeBRP6b, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_4mt6UtDu, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_vkFKW2wP, 0.0f);
  numBytes += cIf_init(&cIf_3frZRta2, false);
  numBytes += cIf_init(&cIf_Wmuq0hNa, false);
  numBytes += cBinop_init(&cBinop_i8NRz2lf, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ZRD7802p, false);
  numBytes += cBinop_init(&cBinop_YBK1Q1f6, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_0iJpb7F4, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_oXQm1Ti6, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_hOKxTDXL, 0.0f);
  numBytes += cIf_init(&cIf_UT8UNGwG, false);
  numBytes += cIf_init(&cIf_d931qRuX, false);
  numBytes += cBinop_init(&cBinop_GLULS8ru, 0.0f); // __pow
  numBytes += cIf_init(&cIf_M2A2C798, false);
  numBytes += cBinop_init(&cBinop_TSpr6uPI, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_RvE3HPVq, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_yoPs7KlS, -15.0f); // __eq
  numBytes += cIf_init(&cIf_o1LN3yZt, false);
  numBytes += cSlice_init(&cSlice_zeSOOtxh, 1, -1);
  numBytes += cVar_init_f(&cVar_z8RveAy7, 0.0f);
  numBytes += cSlice_init(&cSlice_ugDwtWBY, 1, -1);
  numBytes += cVar_init_f(&cVar_yc9pLqa9, 0.0f);
  numBytes += cSlice_init(&cSlice_UJFwnGP6, 1, -1);
  numBytes += cVar_init_f(&cVar_AITo1J5P, 0.0f);
  numBytes += cSlice_init(&cSlice_RHMY6vov, 1, -1);
  numBytes += cVar_init_f(&cVar_aLWTbw3l, 0.313f);
  numBytes += cBinop_init(&cBinop_A9HAurcO, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Qh2OhPiU, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_I8Eq8YWZ, 0.0f);
  numBytes += cVar_init_f(&cVar_iapsyl1a, 1337.0f);
  numBytes += cVar_init_f(&cVar_Ntlwvrks, 0.3f);
  numBytes += cBinop_init(&cBinop_5mhj3ZpT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pYQb1qqz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_q9yFma9M, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jyegJ7eC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5kjxwiud, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SjIrc0I0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4ozUJRpL, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_tbZi4jwf, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_sLwdVm9A, 0.0f);
  numBytes += cVar_init_f(&cVar_R3lVz23F, 1337.0f);
  numBytes += cVar_init_f(&cVar_3Lf0jORj, 0.313f);
  numBytes += cBinop_init(&cBinop_zAiObrVB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7NbbRn1T, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KuVVyfVW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_z6CkGaHA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gq3YryIJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HIaZTvRO, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_MNlhOUjj, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_zi4k4GaL, 0.0f);
  numBytes += cVar_init_f(&cVar_SojdpE5A, 1037.0f);
  numBytes += cVar_init_f(&cVar_wTdm39LM, 0.4f);
  numBytes += cBinop_init(&cBinop_WUlfxyiA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mTXOktmQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QK3Uz0SI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CDm6ojOU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fOYHPTLO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WgBIrrIr, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_QUTf2Unh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MHyFEnnX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wo1naiXK, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lRGLvLu9, 5705.6f);
  numBytes += cVar_init_f(&cVar_tPeMEsUg, 313.3f);
  numBytes += cBinop_init(&cBinop_FYS3r4Lt, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_utPznxm1, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_vysyUoRU, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_aJTdJHcw, 0.0f);
  numBytes += cVar_init_f(&cVar_JHf10oNk, 0.0f);
  numBytes += cVar_init_f(&cVar_xJR8mGhG, 0.0f);
  numBytes += cVar_init_f(&cVar_jhHq8pqp, 0.0f);
  numBytes += cVar_init_f(&cVar_rorHoEZ0, 0.0f);
  numBytes += cVar_init_f(&cVar_pNUywqwc, 0.0f);
  numBytes += cVar_init_f(&cVar_jPNv37sI, 0.0f);
  numBytes += cVar_init_f(&cVar_dikKreHj, 0.0f);
  numBytes += cVar_init_f(&cVar_s8SJFdbl, 0.0f);
  numBytes += cVar_init_f(&cVar_0dBHeCX0, 0.0f);
  numBytes += cVar_init_f(&cVar_S0ukhbKo, 0.0f);
  numBytes += cVar_init_f(&cVar_Ft282RYe, 0.0f);
  numBytes += cVar_init_s(&cVar_NKtslm0A, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_cq1Sb1Z0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FxtHfXUg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LT8n3izE, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_5RjDjue7, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_EgcvD9aH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_buM9bf80, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GPo6zmSo, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_jHFnLTsi, 0.0f);
  numBytes += cDelay_init(this, &cDelay_NVwZ0To1, 0.0f);
  numBytes += hTable_init(&hTable_btcsgDJs, 256);
  numBytes += cDelay_init(this, &cDelay_hHIdJ2S8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_nEsV4k2o, 0.0f);
  numBytes += hTable_init(&hTable_1LHXwIKz, 256);
  numBytes += cVar_init_f(&cVar_zfVmVFmo, 14.0f);
  numBytes += cBinop_init(&cBinop_GxlCdehj, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ClamNtl1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HO6v39qX, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_AQS4sBGN, 14.0f);
  numBytes += cBinop_init(&cBinop_yoencgcj, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_l6jXU40P, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WBHzi58W, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_D37NOsj3, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_905wMUZ7, 1, -1);
  numBytes += cVar_init_f(&cVar_GBTFmcPZ, 0.2f);
  numBytes += cSlice_init(&cSlice_weuRot06, 1, -1);
  numBytes += cVar_init_f(&cVar_gPEpFo2w, 0.0f);
  numBytes += cSlice_init(&cSlice_58rIIhOE, 1, -1);
  numBytes += cVar_init_f(&cVar_uC0ZZNV9, 2.0f);
  numBytes += cSlice_init(&cSlice_PnZXdBMS, 1, -1);
  numBytes += cVar_init_f(&cVar_j89tQxH8, 0.5f);
  numBytes += cVar_init_s(&cVar_EvlQWUwa, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_vWICGudP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_V4k0Ozpf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gQ3w1p4k, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_6gTWELLO, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_SpWVnDqL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Bx94GFU5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RUVkfB07, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_TlNt3356, 0.0f);
  numBytes += cDelay_init(this, &cDelay_iWEc665I, 0.0f);
  numBytes += hTable_init(&hTable_SmkOSjb2, 256);
  numBytes += cDelay_init(this, &cDelay_6myJgbSs, 0.0f);
  numBytes += cDelay_init(this, &cDelay_F3KIyDTt, 0.0f);
  numBytes += hTable_init(&hTable_SGyzbNGb, 256);
  numBytes += cVar_init_f(&cVar_5MrDUEVi, 14.0f);
  numBytes += cBinop_init(&cBinop_lbv1V1HV, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_hast3AJU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FLCaAQsU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_q5gKkwvt, 14.0f);
  numBytes += cBinop_init(&cBinop_XZXqq8vL, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_0aufd0Q0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qZgA9Itk, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_rp4kcpJ4, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_dx6I7eHR, 1, -1);
  numBytes += cVar_init_f(&cVar_bbD8Bbug, 0.2f);
  numBytes += cSlice_init(&cSlice_yGAWwVim, 1, -1);
  numBytes += cVar_init_f(&cVar_EugowjRN, 0.0f);
  numBytes += cSlice_init(&cSlice_riiO3nj1, 1, -1);
  numBytes += cVar_init_f(&cVar_H39txYyn, 2.0f);
  numBytes += cSlice_init(&cSlice_ABHePZtW, 1, -1);
  numBytes += cVar_init_f(&cVar_HC6EJ5p8, 0.5f);
  numBytes += cVar_init_s(&cVar_euUk76ob, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_cq4DDSsX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rnvgcIFN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_svijPbNl, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_LYr0XaCz, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_ai75OyoS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oAo60du5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RpRyvhFl, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_8tKa9Py0, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ug4aCTwv, 0.0f);
  numBytes += hTable_init(&hTable_sU0MT3tE, 256);
  numBytes += cDelay_init(this, &cDelay_F14KMy8x, 0.0f);
  numBytes += cDelay_init(this, &cDelay_JPcV2Zxn, 0.0f);
  numBytes += hTable_init(&hTable_mOUF5EB2, 256);
  numBytes += cVar_init_f(&cVar_rFGo7YX9, 14.0f);
  numBytes += cBinop_init(&cBinop_ndOVxev3, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Ex2YCaeE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lvwdbGwn, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ylF1ZQZn, 14.0f);
  numBytes += cBinop_init(&cBinop_ZxhxzDDH, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ZsyuYOAV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2qclSnF4, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_R3AQg9U6, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_CJc6nP8t, 1, -1);
  numBytes += cVar_init_f(&cVar_cBAMqUra, 0.2f);
  numBytes += cSlice_init(&cSlice_qcFSegAO, 1, -1);
  numBytes += cVar_init_f(&cVar_xxtyXYjO, 0.0f);
  numBytes += cSlice_init(&cSlice_uc3SNbKx, 1, -1);
  numBytes += cVar_init_f(&cVar_3DkVsQK5, 2.0f);
  numBytes += cSlice_init(&cSlice_4fVSgZGA, 1, -1);
  numBytes += cVar_init_f(&cVar_0ctHWm6J, 0.5f);
  numBytes += sVarf_init(&sVarf_VMhBiQK0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OCT6OsQ2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cwNJp3sv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bCCW3Fvm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Yuw0dXBd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FVs3ikSS, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_btcsgDJs);
  hTable_free(&hTable_1LHXwIKz);
  hTable_free(&hTable_SmkOSjb2);
  hTable_free(&hTable_SGyzbNGb);
  hTable_free(&hTable_sU0MT3tE);
  hTable_free(&hTable_mOUF5EB2);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_btcsgDJs; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_1LHXwIKz; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_SmkOSjb2; // del-1397-flanger-r
    case 0x578173CB: return &hTable_SGyzbNGb; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_sU0MT3tE; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_mOUF5EB2; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rm5NRlSu_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aUytVHlB_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Rxllfl5W_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_f6kTBDXY_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RKzbNbz6_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zYFyXbRq_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SAc6hFgf_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zAzGXtl3_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UaLrftUR_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9DOeqE5T_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GSNrDMgp_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_huyI4hGX_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zq46d6jN_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2YL6THoF_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YHPlyuxz_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bpnFOGAN_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_J4po4KVE_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vrZWLVKG_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_os3hwDxh_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G4GxBo08_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XZ7tQsS6_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_p9JE6vZk_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rOK7pRTR_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_N8dkH6yb_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_V2JQc5JB_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bHRGMDuZ_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HVbFzLGD_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XVGfe1AN_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xFJNhQjY_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ue7FvZci_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ms0WeLI4_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9cNvQizn_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4L266jDh_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gAen2o06_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ak3XjFAS_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eN3nUNEc_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ckTUfXQL_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_M5FOneZU_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ny7fLofM_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_a7jwNwGo_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zxjOqzLL_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SUPC5S9Q_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yLanmWNk_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KQFa3H9c_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rS45jPXq_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lvZDvbX2_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XRlEBBvX_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hQ1oLN6f_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_y58wnEqb_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_guCOpA1g_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DEyZ7dWE_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EFdCxz5V_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xdkLyO0V_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UrraDKZX_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uALiMTpq_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uVi53yKc_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MTQsxuQH_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_o8A9tmbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vu1gvfFi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_x9z1Te0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fDVCFRWk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_XqxJaFF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EtvZdqbl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_HXUEig5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mWIMEMnL_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xjm8Wiwp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QVe8l13K_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4dwRM0uu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_0xqkTL6J_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jGrHh9kD, 0, m, &cSlice_jGrHh9kD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NXHhfMJh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_jGrHh9kD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MkkY6uKW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MkkY6uKW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_t8xCIRtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MkkY6uKW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_MkkY6uKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_os3hwDxh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_wNN29RX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KrzPY0Y8_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_5RT9dVVM, 0, m, &cIf_5RT9dVVM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_5RT9dVVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1h7nLX6h_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_FcH5wjrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_5tBzqeMd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Joq9acu0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_Jhym0mJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eioLD2Hc, HV_BINOP_POW, 0, m, &cBinop_eioLD2Hc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eioLD2Hc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nT3O1Eub, 0, m, &cIf_nT3O1Eub_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aKq8w5Bp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_dkEs7DH1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qGkQ10MI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gBL91HrE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_NiuAFa8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FcH5wjrZ, 0, m, &cIf_FcH5wjrZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gBL91HrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FcH5wjrZ, 1, m, &cIf_FcH5wjrZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Joq9acu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_aKq8w5Bp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5tBzqeMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_nT3O1Eub, 0, m, &cIf_nT3O1Eub_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dkEs7DH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eioLD2Hc, HV_BINOP_POW, 1, m, &cBinop_eioLD2Hc_sendMessage);
  cMsg_Jhym0mJA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_nT3O1Eub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_2yV6Qlef, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_KrzPY0Y8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5RT9dVVM, 1, m, &cIf_5RT9dVVM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1h7nLX6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DK0JfwzC, HV_BINOP_GREATER_THAN, 1, m, &cBinop_DK0JfwzC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_b4D0E5tS, HV_BINOP_EQ, 1, m, &cBinop_b4D0E5tS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_g82cWTrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KEYOPRo1, HV_BINOP_ADD, 0, m, &cBinop_KEYOPRo1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KEYOPRo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qGkQ10MI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NiuAFa8d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DK0JfwzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nT3O1Eub, 1, m, &cIf_nT3O1Eub_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_b4D0E5tS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YzfUsP3H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_YzfUsP3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_2yV6Qlef, m);
}

void Heavy_WSTD_FL3NGR::cCast_3tG1XDZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KEYOPRo1, HV_BINOP_ADD, 1, m, &cBinop_KEYOPRo1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DK0JfwzC, HV_BINOP_GREATER_THAN, 0, m, &cBinop_DK0JfwzC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_b4D0E5tS, HV_BINOP_EQ, 0, m, &cBinop_b4D0E5tS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CuBM2X3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g82cWTrR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_s0DIDd1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wNN29RX1, 0, m, &cVar_wNN29RX1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_hYfdJxDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_u83E355L_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_9DxEjU8l, 0, m, &cIf_9DxEjU8l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_9DxEjU8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_v70H91kO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_IaLbijYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_X0Zi4jBO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_XqSAhII0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_jk99b80b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oSjDlcFZ, HV_BINOP_POW, 0, m, &cBinop_oSjDlcFZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oSjDlcFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nGeaoHFx, 0, m, &cIf_nGeaoHFx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_R0i37CUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ry17b5TO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rWXxji7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IaLbijYJ, 0, m, &cIf_IaLbijYJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6HNgOJI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mv2Q3xT0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mv2Q3xT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IaLbijYJ, 1, m, &cIf_IaLbijYJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XqSAhII0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_R0i37CUz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_X0Zi4jBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_nGeaoHFx, 0, m, &cIf_nGeaoHFx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ry17b5TO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oSjDlcFZ, HV_BINOP_POW, 1, m, &cBinop_oSjDlcFZ_sendMessage);
  cMsg_jk99b80b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_nGeaoHFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bc45yagz_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kXrJexCE_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_3L96pEcD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_u83E355L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9DxEjU8l, 1, m, &cIf_9DxEjU8l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_v70H91kO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uZIOkf7G, HV_BINOP_GREATER_THAN, 1, m, &cBinop_uZIOkf7G_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FmRn6oUd, HV_BINOP_EQ, 1, m, &cBinop_FmRn6oUd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_96L2PIXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pv8qagIY, HV_BINOP_ADD, 0, m, &cBinop_Pv8qagIY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Pv8qagIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6HNgOJI9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rWXxji7P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uZIOkf7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nGeaoHFx, 1, m, &cIf_nGeaoHFx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FmRn6oUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LyxlQFVQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_LyxlQFVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bc45yagz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kXrJexCE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_3L96pEcD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_f4Eof832_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hYfdJxDv, 0, m, &cVar_hYfdJxDv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8qLAzEzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pv8qagIY, HV_BINOP_ADD, 1, m, &cBinop_Pv8qagIY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uZIOkf7G, HV_BINOP_GREATER_THAN, 0, m, &cBinop_uZIOkf7G_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FmRn6oUd, HV_BINOP_EQ, 0, m, &cBinop_FmRn6oUd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Lnp0TC5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_96L2PIXs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ArzTSclC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nQ2UnVSU_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_wVpVb2Jy, 0, m, &cIf_wVpVb2Jy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_wVpVb2Jy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1pQnr208_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_DBGtGgkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_t0tOWZyc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ApCAfcFi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_ZaZD5H5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_njhgRydX, HV_BINOP_POW, 0, m, &cBinop_njhgRydX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_njhgRydX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yX7yapek, 0, m, &cIf_yX7yapek_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wegaDnYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_V38WR4n2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zEO3asI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_D439EXiv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gnt2AIVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DBGtGgkp, 0, m, &cIf_DBGtGgkp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_D439EXiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DBGtGgkp, 1, m, &cIf_DBGtGgkp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ApCAfcFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_wegaDnYP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_t0tOWZyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_yX7yapek, 0, m, &cIf_yX7yapek_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_V38WR4n2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_njhgRydX, HV_BINOP_POW, 1, m, &cBinop_njhgRydX_sendMessage);
  cMsg_ZaZD5H5n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_yX7yapek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_3E1bPcDT, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_nQ2UnVSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wVpVb2Jy, 1, m, &cIf_wVpVb2Jy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1pQnr208_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Iw4bl0L2, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Iw4bl0L2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_g0pJ88uS, HV_BINOP_EQ, 1, m, &cBinop_g0pJ88uS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1LwT7sil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WJf40oip, HV_BINOP_ADD, 0, m, &cBinop_WJf40oip_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WJf40oip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zEO3asI7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gnt2AIVK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Iw4bl0L2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yX7yapek, 1, m, &cIf_yX7yapek_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g0pJ88uS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FeSWJr5Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_FeSWJr5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_3E1bPcDT, m);
}

void Heavy_WSTD_FL3NGR::cCast_2kxriEHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WJf40oip, HV_BINOP_ADD, 1, m, &cBinop_WJf40oip_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Iw4bl0L2, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Iw4bl0L2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_g0pJ88uS, HV_BINOP_EQ, 0, m, &cBinop_g0pJ88uS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6OffAc7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ArzTSclC, 0, m, &cVar_ArzTSclC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vIv4zZtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1LwT7sil_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_fH6Ksvcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_7s7XzUZ3, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_LUZUPBSA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5Sk6mgpL, 0, m, &cSlice_5Sk6mgpL_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2VQhXNjq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_5Sk6mgpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yV6bc5nC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yV6bc5nC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ZZ0PPLjI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yV6bc5nC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_yV6bc5nC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_J4po4KVE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_2VQhXNjq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NTKtdRbB, 0, m, &cSlice_NTKtdRbB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0xqkTL6J_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_NTKtdRbB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_x5WnX6Ja_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_x5WnX6Ja_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_Ldne6noG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_x5WnX6Ja_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_x5WnX6Ja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XZ7tQsS6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_NXHhfMJh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_f89j1p3M, 0, m, &cSlice_f89j1p3M_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cXpAEimR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_f89j1p3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_w61RshJB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_w61RshJB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_yWd8Wncu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_w61RshJB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_w61RshJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vrZWLVKG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_cXpAEimR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nmu5E0dr, 0, m, &cSlice_nmu5E0dr_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_nmu5E0dr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sigiyKiX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sigiyKiX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_fieuYC5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sigiyKiX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_sigiyKiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_G4GxBo08_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_RVN6yWLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1Gx7Y2HF, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_oZV7TUDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZYCXxeBS, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_fdnOHekN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Mh7UIyif, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_o8f5NmjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zrZ8Zn9V, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_t0iZUICs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8FvoQI2x, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_lHkydcA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_j98hUQZm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_j98hUQZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gwX2yQxf, HV_BINOP_DIVIDE, 1, m, &cBinop_gwX2yQxf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cBIlrTX1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_0ulDQZhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Q1j471Md_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_J6Au29G2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_0ulDQZhS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Q1j471Md_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gwX2yQxf, HV_BINOP_DIVIDE, 0, m, &cBinop_gwX2yQxf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_cBIlrTX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J6Au29G2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gwX2yQxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KG7twc9a, HV_BINOP_MULTIPLY, 1, m, &cBinop_KG7twc9a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KG7twc9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6hkbPzy1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E18iNkbw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_2Si0qWaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Li8owNix_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_mX9zFbec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5G6hmM8d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_etdsnXWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ckWRxUxz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ckWRxUxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KG7twc9a, HV_BINOP_MULTIPLY, 0, m, &cBinop_KG7twc9a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Qp8nH2jW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_lusuwpWz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lusuwpWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ptN2wkIA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_I6q0wFG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QCyDj6EP, 1, m, &cVar_QCyDj6EP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_QCyDj6EP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l9MXVBC9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CCZNeuIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FvDs0oBc, HV_BINOP_MULTIPLY, 1, m, &cBinop_FvDs0oBc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WNHUwfPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CCZNeuIU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vQMc1MJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9ZeG8UXk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9ZeG8UXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ScYHXUvh, HV_BINOP_MULTIPLY, 1, m, &cBinop_ScYHXUvh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iqnvN5Fe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I652hys4, HV_BINOP_MULTIPLY, 1, m, &cBinop_I652hys4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CMqTMnq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_iqnvN5Fe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VftjdrLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WUSWYwR7, HV_BINOP_MULTIPLY, 1, m, &cBinop_WUSWYwR7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YR8nR7sN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_s9PGx23M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_s9PGx23M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q6aLCPJG, HV_BINOP_MULTIPLY, 1, m, &cBinop_q6aLCPJG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_pk1hMEiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ozvWOMoX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_etdsnXWB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GcByhba1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_CeeyKK6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Qp8nH2jW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_E18iNkbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_mX9zFbec_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6hkbPzy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_2Si0qWaZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_Li8owNix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_N8dkH6yb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_5G6hmM8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rOK7pRTR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_T5wmy748_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_p9JE6vZk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ptN2wkIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pNDNG3h8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pNDNG3h8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rf9ikTkF, HV_BINOP_MULTIPLY, 1, m, &cBinop_Rf9ikTkF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Rf9ikTkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8K58U1Xr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8K58U1Xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_T5wmy748_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_l9MXVBC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fq1wTu37_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fq1wTu37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NSeDgyiL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i96t6mHN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LksoBoSQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VSvNvQhn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_87hfjpYV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sJTcYToA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FvDs0oBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RVN6yWLh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ScYHXUvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oZV7TUDf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_I652hys4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fdnOHekN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WUSWYwR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o8f5NmjQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_q6aLCPJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t0iZUICs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_dJ1djJFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CeeyKK6Z, 1, m, &cVar_CeeyKK6Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jOY0fSrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pk1hMEiu, 0, m, &cVar_pk1hMEiu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_87hfjpYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ScYHXUvh, HV_BINOP_MULTIPLY, 0, m, &cBinop_ScYHXUvh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LksoBoSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WUSWYwR7, HV_BINOP_MULTIPLY, 0, m, &cBinop_WUSWYwR7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VSvNvQhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I652hys4, HV_BINOP_MULTIPLY, 0, m, &cBinop_I652hys4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_i96t6mHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q6aLCPJG, HV_BINOP_MULTIPLY, 0, m, &cBinop_q6aLCPJG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sJTcYToA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FvDs0oBc, HV_BINOP_MULTIPLY, 0, m, &cBinop_FvDs0oBc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_NSeDgyiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_ozvWOMoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CeeyKK6Z, 0, m, &cVar_CeeyKK6Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GcByhba1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QCyDj6EP, 0, m, &cVar_QCyDj6EP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_i5t6Ouau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BNTXFjSi, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_W6jCCFAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tUFVb7Fh, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Di0f5tvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M0Qx4cDN, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_YAEnOJgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ig5Dd3Oq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_AR57xBd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gKuvOqWR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_gKuvOqWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PpRhCssl, HV_BINOP_DIVIDE, 1, m, &cBinop_PpRhCssl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v3ZX3CSD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_ioIP0b4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_x1W5NtFA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_FarJ2Ths_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ioIP0b4h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_x1W5NtFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PpRhCssl, HV_BINOP_DIVIDE, 0, m, &cBinop_PpRhCssl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_v3ZX3CSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FarJ2Ths_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_PpRhCssl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2fxL7upP, HV_BINOP_MULTIPLY, 1, m, &cBinop_2fxL7upP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2fxL7upP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aSs7JBSO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_alllxZNw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_QEVrIbTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NcHRh0zH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_PX1nEILf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0QVbSyA4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_QySDMLlO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Fv2k8EYi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Fv2k8EYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2fxL7upP, HV_BINOP_MULTIPLY, 0, m, &cBinop_2fxL7upP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6ROjtfan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_lnxXsFwV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lnxXsFwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9WeDnesY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Bktxexqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wO6nqpvv, HV_BINOP_MULTIPLY, 1, m, &cBinop_wO6nqpvv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bnfk6lN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bKkBXD23, 1, m, &cVar_bKkBXD23_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HlXTmeF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lkux9z5e, HV_BINOP_MULTIPLY, 1, m, &cBinop_lkux9z5e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_gMEKQz1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_K02Y0RQh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_K02Y0RQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zLOZFuCS, HV_BINOP_MULTIPLY, 1, m, &cBinop_zLOZFuCS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_bKkBXD23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6NJH7dUX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_nh9RBBpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HoLKLoAA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_QySDMLlO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uXKYE8Lj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_vKxlPOVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_6ROjtfan_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_alllxZNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_PX1nEILf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_aSs7JBSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_QEVrIbTQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_NcHRh0zH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HVbFzLGD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_0QVbSyA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bHRGMDuZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_lJnsPpWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_V2JQc5JB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_9WeDnesY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_CtVGo9gY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CtVGo9gY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v8MEoQ7x, HV_BINOP_MULTIPLY, 1, m, &cBinop_v8MEoQ7x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_v8MEoQ7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cnpKcMl0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cnpKcMl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lJnsPpWN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_6NJH7dUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_BEB0XlVD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BEB0XlVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KE8Oxhbp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xiXN9mhr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GjGZ4Ufw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r6Bgups5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_y8xrknEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i5t6Ouau_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wO6nqpvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W6jCCFAh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_lkux9z5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Di0f5tvn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_zLOZFuCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YAEnOJgL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_xcXxz3QP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nh9RBBpq, 0, m, &cVar_nh9RBBpq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_M714wBAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vKxlPOVz, 1, m, &cVar_vKxlPOVz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_uXKYE8Lj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bKkBXD23, 0, m, &cVar_bKkBXD23_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HoLKLoAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vKxlPOVz, 0, m, &cVar_vKxlPOVz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GjGZ4Ufw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wO6nqpvv, HV_BINOP_MULTIPLY, 0, m, &cBinop_wO6nqpvv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xiXN9mhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lkux9z5e, HV_BINOP_MULTIPLY, 0, m, &cBinop_lkux9z5e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_KE8Oxhbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zLOZFuCS, HV_BINOP_MULTIPLY, 0, m, &cBinop_zLOZFuCS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_r6Bgups5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y8xrknEB, HV_BINOP_MULTIPLY, 0, m, &cBinop_y8xrknEB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fa1p1ABd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B2RVniFC, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_dyweRwsj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UMedoi9s, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_7IjzZics_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UlGSEZ28, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Q01EF7vy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Zj57gEy9, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_3nqvEd7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qEEzkQ9W, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_S3B6uoww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fqzYftdi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_fqzYftdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_znYrjeXU, HV_BINOP_DIVIDE, 1, m, &cBinop_znYrjeXU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iC49gFqm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_vFnZvTLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_vx2DRPoB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YBW6PJmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_vFnZvTLu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vx2DRPoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_znYrjeXU, HV_BINOP_DIVIDE, 0, m, &cBinop_znYrjeXU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iC49gFqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YBW6PJmQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_znYrjeXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DXTQCRnE, HV_BINOP_MULTIPLY, 1, m, &cBinop_DXTQCRnE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DXTQCRnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hbd7NPjq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pM5Ud7O3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_JQ06jNBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0dYLC3tX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_dVW66hEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IinbDJFM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_hMFHUOO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_7KlMa5Lo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7KlMa5Lo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DXTQCRnE, HV_BINOP_MULTIPLY, 0, m, &cBinop_DXTQCRnE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_my5tHjCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_HuZvdkZn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HuZvdkZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wAO9ds7F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WzaYRPHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yVdJEmcH, HV_BINOP_MULTIPLY, 1, m, &cBinop_yVdJEmcH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9huyTX7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_lsUbCyk7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lsUbCyk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WzaYRPHB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_pxtoble4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_clFVwFo9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_clFVwFo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VsypA919, HV_BINOP_MULTIPLY, 1, m, &cBinop_VsypA919_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WyEnpqcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zYPXQyyd, HV_BINOP_MULTIPLY, 1, m, &cBinop_zYPXQyyd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0Xv7pqTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_31BBxlsu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_31BBxlsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WyEnpqcr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9zYZ1Z5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MbLFGxnB, 1, m, &cVar_MbLFGxnB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mrKZgaGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FIB2GR2D, HV_BINOP_MULTIPLY, 1, m, &cBinop_FIB2GR2D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KVPTeWQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yrBWCdcC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yrBWCdcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KsB9diWF, HV_BINOP_MULTIPLY, 1, m, &cBinop_KsB9diWF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_MbLFGxnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gTHqRSyV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_WxTn34EO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mhaJXfiv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_hMFHUOO0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MUU0FMxY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_MZ8OWomb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_my5tHjCb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pM5Ud7O3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_dVW66hEv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hbd7NPjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_JQ06jNBd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_0dYLC3tX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ue7FvZci_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_IinbDJFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xFJNhQjY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_6TcJMrZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XVGfe1AN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_wAO9ds7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_f4uJrfz9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_f4uJrfz9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gSfj5WmF, HV_BINOP_MULTIPLY, 1, m, &cBinop_gSfj5WmF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gSfj5WmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XdCtCtRU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XdCtCtRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6TcJMrZl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_gTHqRSyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_z0xhmmZs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_z0xhmmZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DoL3Yimy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lT9C8TkO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7WZ2LFH7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pTsAB2Su_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vixi0aS6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aVEHwpYR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yVdJEmcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fa1p1ABd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_VsypA919_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dyweRwsj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_zYPXQyyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7IjzZics_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_FIB2GR2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q01EF7vy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KsB9diWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3nqvEd7q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_GuIXTxrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WxTn34EO, 0, m, &cVar_WxTn34EO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wtSYyMjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MZ8OWomb, 1, m, &cVar_MZ8OWomb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_aVEHwpYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yVdJEmcH, HV_BINOP_MULTIPLY, 0, m, &cBinop_yVdJEmcH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lT9C8TkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KsB9diWF, HV_BINOP_MULTIPLY, 0, m, &cBinop_KsB9diWF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Vixi0aS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VsypA919, HV_BINOP_MULTIPLY, 0, m, &cBinop_VsypA919_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7WZ2LFH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FIB2GR2D, HV_BINOP_MULTIPLY, 0, m, &cBinop_FIB2GR2D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_DoL3Yimy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_pTsAB2Su_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zYPXQyyd, HV_BINOP_MULTIPLY, 0, m, &cBinop_zYPXQyyd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MUU0FMxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MbLFGxnB, 0, m, &cVar_MbLFGxnB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mhaJXfiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MZ8OWomb, 0, m, &cVar_MZ8OWomb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bc45yagz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fH6Ksvcp, 1, m, &cIf_fH6Ksvcp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_cZKpLin0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7s7XzUZ3, m);
}

void Heavy_WSTD_FL3NGR::cBinop_kXrJexCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cZKpLin0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3L96pEcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fH6Ksvcp, 0, m, &cIf_fH6Ksvcp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_9OPjR6W7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ILcfPKvl, 0, m, &cSlice_ILcfPKvl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3xS8uVHQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ILcfPKvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_n8uYkJIO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_n8uYkJIO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_JUHR9hFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_n8uYkJIO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_n8uYkJIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4L266jDh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_7MsDGqAr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8jqHlskB_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_vMztCwGj, 0, m, &cIf_vMztCwGj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_vMztCwGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_yig4nNlb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_jF6StMHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_KoghTFFL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_wfv9hwX6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_YcIFdnz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uBVTUlXJ, HV_BINOP_POW, 0, m, &cBinop_uBVTUlXJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uBVTUlXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PPPBo8Bt, 0, m, &cIf_PPPBo8Bt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BjHbgYPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_YqSfckma_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0Fk8B1Yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jF6StMHi, 0, m, &cIf_jF6StMHi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_A4yMq8My_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qSKd2UBY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qSKd2UBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jF6StMHi, 1, m, &cIf_jF6StMHi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wfv9hwX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_BjHbgYPV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KoghTFFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_PPPBo8Bt, 0, m, &cIf_PPPBo8Bt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YqSfckma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uBVTUlXJ, HV_BINOP_POW, 1, m, &cBinop_uBVTUlXJ_sendMessage);
  cMsg_YcIFdnz6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_PPPBo8Bt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_QUTf2Unh, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_8jqHlskB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vMztCwGj, 1, m, &cIf_vMztCwGj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yig4nNlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eUeBRP6b, HV_BINOP_GREATER_THAN, 1, m, &cBinop_eUeBRP6b_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4mt6UtDu, HV_BINOP_EQ, 1, m, &cBinop_4mt6UtDu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4afhmrIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Usc4HXAW, HV_BINOP_ADD, 0, m, &cBinop_Usc4HXAW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Usc4HXAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A4yMq8My_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0Fk8B1Yo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eUeBRP6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PPPBo8Bt, 1, m, &cIf_PPPBo8Bt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4mt6UtDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vRRj1HUf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_vRRj1HUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QUTf2Unh, m);
}

void Heavy_WSTD_FL3NGR::cCast_4cjNPXuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4afhmrIo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_hBEz3iEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Usc4HXAW, HV_BINOP_ADD, 1, m, &cBinop_Usc4HXAW_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eUeBRP6b, HV_BINOP_GREATER_THAN, 0, m, &cBinop_eUeBRP6b_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4mt6UtDu, HV_BINOP_EQ, 0, m, &cBinop_4mt6UtDu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_KEvi7Ao8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7MsDGqAr, 0, m, &cVar_7MsDGqAr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_vkFKW2wP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MfDcHxBL_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_3frZRta2, 0, m, &cIf_3frZRta2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_3frZRta2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_F1xZcgwV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_Wmuq0hNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_tERjTuxl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_DiR3Pjj0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_5R3gTxW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_i8NRz2lf, HV_BINOP_POW, 0, m, &cBinop_i8NRz2lf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_i8NRz2lf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZRD7802p, 0, m, &cIf_ZRD7802p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6fc4Aucw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_YBd87jFv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Z3oZjOvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wmuq0hNa, 0, m, &cIf_Wmuq0hNa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_v0n02jNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UO3lf5Ta_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UO3lf5Ta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wmuq0hNa, 1, m, &cIf_Wmuq0hNa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DiR3Pjj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_6fc4Aucw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tERjTuxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ZRD7802p, 0, m, &cIf_ZRD7802p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YBd87jFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i8NRz2lf, HV_BINOP_POW, 1, m, &cBinop_i8NRz2lf_sendMessage);
  cMsg_5R3gTxW2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_ZRD7802p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wGJ9BD03_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WlQJ9z0J_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_wDv0b3M8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_MfDcHxBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3frZRta2, 1, m, &cIf_3frZRta2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_F1xZcgwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0iJpb7F4, HV_BINOP_GREATER_THAN, 1, m, &cBinop_0iJpb7F4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oXQm1Ti6, HV_BINOP_EQ, 1, m, &cBinop_oXQm1Ti6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DzyYjMLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YBK1Q1f6, HV_BINOP_ADD, 0, m, &cBinop_YBK1Q1f6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YBK1Q1f6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v0n02jNB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z3oZjOvl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0iJpb7F4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZRD7802p, 1, m, &cIf_ZRD7802p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oXQm1Ti6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CJXFRTam_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_CJXFRTam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wGJ9BD03_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WlQJ9z0J_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_wDv0b3M8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1oKBwYMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vkFKW2wP, 0, m, &cVar_vkFKW2wP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iCkc3JpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DzyYjMLM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_xxo6MXfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YBK1Q1f6, HV_BINOP_ADD, 1, m, &cBinop_YBK1Q1f6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0iJpb7F4, HV_BINOP_GREATER_THAN, 0, m, &cBinop_0iJpb7F4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oXQm1Ti6, HV_BINOP_EQ, 0, m, &cBinop_oXQm1Ti6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_hOKxTDXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5KNCeFl8_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_UT8UNGwG, 0, m, &cIf_UT8UNGwG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_UT8UNGwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4qBgi5ID_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_d931qRuX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_w6ODz5X1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_anBBcs9u_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_D6mm5D8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GLULS8ru, HV_BINOP_POW, 0, m, &cBinop_GLULS8ru_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GLULS8ru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M2A2C798, 0, m, &cIf_M2A2C798_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZSJffATi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_5fBH5YLf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_BLljPFS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d931qRuX, 0, m, &cIf_d931qRuX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xSg3RXgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_N0gYBxGC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_N0gYBxGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d931qRuX, 1, m, &cIf_d931qRuX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_anBBcs9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ZSJffATi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_w6ODz5X1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_M2A2C798, 0, m, &cIf_M2A2C798_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5fBH5YLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GLULS8ru, HV_BINOP_POW, 1, m, &cBinop_GLULS8ru_sendMessage);
  cMsg_D6mm5D8W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_M2A2C798_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_wo1naiXK, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_5KNCeFl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UT8UNGwG, 1, m, &cIf_UT8UNGwG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4qBgi5ID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RvE3HPVq, HV_BINOP_GREATER_THAN, 1, m, &cBinop_RvE3HPVq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yoPs7KlS, HV_BINOP_EQ, 1, m, &cBinop_yoPs7KlS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2Epy3vtt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TSpr6uPI, HV_BINOP_ADD, 0, m, &cBinop_TSpr6uPI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TSpr6uPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xSg3RXgb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BLljPFS7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RvE3HPVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M2A2C798, 1, m, &cIf_M2A2C798_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yoPs7KlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lbR2pf0m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_lbR2pf0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wo1naiXK, m);
}

void Heavy_WSTD_FL3NGR::cCast_vZDsGjeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hOKxTDXL, 0, m, &cVar_hOKxTDXL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QSV9ycvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2Epy3vtt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_zVUHEhjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TSpr6uPI, HV_BINOP_ADD, 1, m, &cBinop_TSpr6uPI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RvE3HPVq, HV_BINOP_GREATER_THAN, 0, m, &cBinop_RvE3HPVq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yoPs7KlS, HV_BINOP_EQ, 0, m, &cBinop_yoPs7KlS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_o1LN3yZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_MHyFEnnX, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_qg2dFEBP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zeSOOtxh, 0, m, &cSlice_zeSOOtxh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ReAXBfoL_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_zeSOOtxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DPOGJc2K_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DPOGJc2K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_z8RveAy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DPOGJc2K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_DPOGJc2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ms0WeLI4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_ReAXBfoL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ugDwtWBY, 0, m, &cSlice_ugDwtWBY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9OPjR6W7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ugDwtWBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QPIywgPi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QPIywgPi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_yc9pLqa9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QPIywgPi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_QPIywgPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ak3XjFAS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_3xS8uVHQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UJFwnGP6, 0, m, &cSlice_UJFwnGP6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FNDqDcYD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_UJFwnGP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YgqHjXJs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YgqHjXJs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_AITo1J5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YgqHjXJs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_YgqHjXJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9cNvQizn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_FNDqDcYD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RHMY6vov, 0, m, &cSlice_RHMY6vov_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_RHMY6vov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9J0agMtv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9J0agMtv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_aLWTbw3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9J0agMtv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_9J0agMtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gAen2o06_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_PXFzAS3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_70jxgnyg, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_aO5P9FdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fMHKhqQY, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Z8PKE4Vi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o3j1ELj8, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_KvwRi9dW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h0GpShuZ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ip6hIx9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T4A5wP6B, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_4gUvuK59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BSPzG4pJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_BSPzG4pJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A9HAurcO, HV_BINOP_DIVIDE, 1, m, &cBinop_A9HAurcO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rwqH9PnR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_E8aWe0Aa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_rW7zRMoT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_znEPTqjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_E8aWe0Aa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rW7zRMoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A9HAurcO, HV_BINOP_DIVIDE, 0, m, &cBinop_A9HAurcO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rwqH9PnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_znEPTqjq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_A9HAurcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qh2OhPiU, HV_BINOP_MULTIPLY, 1, m, &cBinop_Qh2OhPiU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Qh2OhPiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QlHx2tgP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8Shf593C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_NLP0zDk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qlXFc0tW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_3nY2wSmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zZ9ZNhpW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_VJDrFi9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_dygMCBDf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dygMCBDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qh2OhPiU, HV_BINOP_MULTIPLY, 0, m, &cBinop_Qh2OhPiU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ALcem4Wo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ri2pZSIZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ri2pZSIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CDSW6m2e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_9XutMVjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I8Eq8YWZ, 1, m, &cVar_I8Eq8YWZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_I8Eq8YWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xn3Xzeqc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_EdZ4laub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pYQb1qqz, HV_BINOP_MULTIPLY, 1, m, &cBinop_pYQb1qqz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bGIeJpAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EdZ4laub_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pRWdhTUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8jvEhMiF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8jvEhMiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q9yFma9M, HV_BINOP_MULTIPLY, 1, m, &cBinop_q9yFma9M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_K0DzwYD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jyegJ7eC, HV_BINOP_MULTIPLY, 1, m, &cBinop_jyegJ7eC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AqpMzNYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_K0DzwYD5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9PwaMMLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5kjxwiud, HV_BINOP_MULTIPLY, 1, m, &cBinop_5kjxwiud_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ewecwcwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_RzQVFTJq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RzQVFTJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SjIrc0I0, HV_BINOP_MULTIPLY, 1, m, &cBinop_SjIrc0I0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_iapsyl1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KEDNMMnD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_VJDrFi9Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d8m7G2rs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Ntlwvrks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ALcem4Wo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QlHx2tgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_NLP0zDk5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8Shf593C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_3nY2wSmj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_qlXFc0tW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_M5FOneZU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_zZ9ZNhpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ckTUfXQL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_GGsDvdod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eN3nUNEc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_CDSW6m2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Su7MuHYT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Su7MuHYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5mhj3ZpT, HV_BINOP_MULTIPLY, 1, m, &cBinop_5mhj3ZpT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5mhj3ZpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_c5Dz0XrW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_c5Dz0XrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GGsDvdod_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_xn3Xzeqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_f1b7zlX3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_f1b7zlX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y4J0yGNW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6FNH5j33_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9cZpqNAs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vice2Ob4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TtcYj6C7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6bT0KeVj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pYQb1qqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PXFzAS3q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_q9yFma9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aO5P9FdX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_jyegJ7eC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z8PKE4Vi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5kjxwiud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KvwRi9dW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_SjIrc0I0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ip6hIx9F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_3EU7S8AY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ntlwvrks, 1, m, &cVar_Ntlwvrks_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6q6UubmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iapsyl1a, 0, m, &cVar_iapsyl1a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6bT0KeVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pYQb1qqz, HV_BINOP_MULTIPLY, 0, m, &cBinop_pYQb1qqz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6FNH5j33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SjIrc0I0, HV_BINOP_MULTIPLY, 0, m, &cBinop_SjIrc0I0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vice2Ob4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jyegJ7eC, HV_BINOP_MULTIPLY, 0, m, &cBinop_jyegJ7eC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9cZpqNAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5kjxwiud, HV_BINOP_MULTIPLY, 0, m, &cBinop_5kjxwiud_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TtcYj6C7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q9yFma9M, HV_BINOP_MULTIPLY, 0, m, &cBinop_q9yFma9M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_y4J0yGNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_d8m7G2rs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I8Eq8YWZ, 0, m, &cVar_I8Eq8YWZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_KEDNMMnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ntlwvrks, 0, m, &cVar_Ntlwvrks_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_dHGhUpNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YkAO5F8i, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_kYmvpqCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8i2nqTKK, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_eQYbTrec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qEk3Po23, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_k9E8dRLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qjpZEpFl, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_1cCmbae5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_E96LllRY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_E96LllRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4ozUJRpL, HV_BINOP_DIVIDE, 1, m, &cBinop_4ozUJRpL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eVkz3TG5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_z41KaFMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_fAAyLDq9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1esTNKRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_z41KaFMU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fAAyLDq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4ozUJRpL, HV_BINOP_DIVIDE, 0, m, &cBinop_4ozUJRpL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_eVkz3TG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1esTNKRV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_4ozUJRpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tbZi4jwf, HV_BINOP_MULTIPLY, 1, m, &cBinop_tbZi4jwf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tbZi4jwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ujgYdFi2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A9IcGg7J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_VIoQIofH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_D8NAIv6N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_PDsWB6jz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ROTKYHbZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_oWIFtNDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_9zz2id2j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9zz2id2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tbZi4jwf, HV_BINOP_MULTIPLY, 0, m, &cBinop_tbZi4jwf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dwau0mAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_6INjODMM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6INjODMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GgsjYCUE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KyiXzyXQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KuVVyfVW, HV_BINOP_MULTIPLY, 1, m, &cBinop_KuVVyfVW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7mlgaU9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sLwdVm9A, 1, m, &cVar_sLwdVm9A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ETb3cZtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z6CkGaHA, HV_BINOP_MULTIPLY, 1, m, &cBinop_z6CkGaHA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CYkDgfCD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ycQkiWGq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ycQkiWGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gq3YryIJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_gq3YryIJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_sLwdVm9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jrsJ0sEi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_R3lVz23F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WYUVrkkF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_oWIFtNDF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rqDBikE1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_3Lf0jORj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_dwau0mAM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_A9IcGg7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_PDsWB6jz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ujgYdFi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_VIoQIofH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_D8NAIv6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zxjOqzLL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_ROTKYHbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_a7jwNwGo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_aApkOKNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ny7fLofM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_GgsjYCUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_w129fluG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_w129fluG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zAiObrVB, HV_BINOP_MULTIPLY, 1, m, &cBinop_zAiObrVB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zAiObrVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5JdBfhVB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5JdBfhVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aApkOKNo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_jrsJ0sEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RHjSMoDA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RHjSMoDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NQ0TKqjd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Jl6kONjP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OTLnRgl0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_euv43CQO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7NbbRn1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dHGhUpNC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KuVVyfVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kYmvpqCy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_z6CkGaHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eQYbTrec_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gq3YryIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k9E8dRLb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_nmcqnlBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R3lVz23F, 0, m, &cVar_R3lVz23F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3AOaAICg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3Lf0jORj, 1, m, &cVar_3Lf0jORj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_WYUVrkkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3Lf0jORj, 0, m, &cVar_3Lf0jORj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rqDBikE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sLwdVm9A, 0, m, &cVar_sLwdVm9A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Jl6kONjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z6CkGaHA, HV_BINOP_MULTIPLY, 0, m, &cBinop_z6CkGaHA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_NQ0TKqjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gq3YryIJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_gq3YryIJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_euv43CQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7NbbRn1T, HV_BINOP_MULTIPLY, 0, m, &cBinop_7NbbRn1T_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OTLnRgl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KuVVyfVW, HV_BINOP_MULTIPLY, 0, m, &cBinop_KuVVyfVW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DFJ1CwH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JU0cfcXC, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_UcAklCG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zXwZug79, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Yxg4skan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ubcys9bZ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_YDkrBThp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hy2GDL01, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_yS6is3HP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F2Yy0nTJ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_cBsr17gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JXroExyd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_JXroExyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HIaZTvRO, HV_BINOP_DIVIDE, 1, m, &cBinop_HIaZTvRO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hXEqQLqZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_SuCpQGpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_oZkhOPYr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mO97ko1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_SuCpQGpg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oZkhOPYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HIaZTvRO, HV_BINOP_DIVIDE, 0, m, &cBinop_HIaZTvRO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hXEqQLqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mO97ko1w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HIaZTvRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MNlhOUjj, HV_BINOP_MULTIPLY, 1, m, &cBinop_MNlhOUjj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MNlhOUjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kaWrAAfH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MBWeRhSX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_oQqPVbf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FIx7mT2p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_yKU0jsVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ssUf2Pi9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CBZIM7Wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_KtSkXF3Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KtSkXF3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MNlhOUjj, HV_BINOP_MULTIPLY, 0, m, &cBinop_MNlhOUjj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_H7BTozQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_6zEAq9JT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6zEAq9JT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mxtisrkj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NakQo9VU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mTXOktmQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_mTXOktmQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_XgYTWdQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EP72TrKh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EP72TrKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NakQo9VU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_PuQopHxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YXRa43bQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YXRa43bQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QK3Uz0SI, HV_BINOP_MULTIPLY, 1, m, &cBinop_QK3Uz0SI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FduPoqSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CDm6ojOU, HV_BINOP_MULTIPLY, 1, m, &cBinop_CDm6ojOU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CYybo9VA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_a1KDlyNK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_a1KDlyNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FduPoqSY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HegYJ5Yk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zi4k4GaL, 1, m, &cVar_zi4k4GaL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WqjpcULp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fOYHPTLO, HV_BINOP_MULTIPLY, 1, m, &cBinop_fOYHPTLO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_uoUzq7vc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_G6RIgm1i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_G6RIgm1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WgBIrrIr, HV_BINOP_MULTIPLY, 1, m, &cBinop_WgBIrrIr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_zi4k4GaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jth489Po_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_SojdpE5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lJqcGtf4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_CBZIM7Wg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JGGAE0jM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_wTdm39LM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_H7BTozQL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kaWrAAfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_oQqPVbf7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MBWeRhSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_yKU0jsVa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_FIx7mT2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KQFa3H9c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_ssUf2Pi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yLanmWNk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_RxFNIkFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SUPC5S9Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_mxtisrkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VDE77zxH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VDE77zxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WUlfxyiA, HV_BINOP_MULTIPLY, 1, m, &cBinop_WUlfxyiA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WUlfxyiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_fn8D8IfI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fn8D8IfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RxFNIkFA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_jth489Po_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ouSEVqqH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ouSEVqqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_voh0DVYn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ch5zUBIk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MeXULi4I_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JkC245rz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ylEl3JhK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7L7Kg3NA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mTXOktmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DFJ1CwH7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_QK3Uz0SI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UcAklCG4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CDm6ojOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yxg4skan_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_fOYHPTLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YDkrBThp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WgBIrrIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yS6is3HP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_AXexylBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SojdpE5A, 0, m, &cVar_SojdpE5A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_R7fS4Iai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wTdm39LM, 1, m, &cVar_wTdm39LM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ch5zUBIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WgBIrrIr, HV_BINOP_MULTIPLY, 0, m, &cBinop_WgBIrrIr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7L7Kg3NA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mTXOktmQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_mTXOktmQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ylEl3JhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QK3Uz0SI, HV_BINOP_MULTIPLY, 0, m, &cBinop_QK3Uz0SI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MeXULi4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fOYHPTLO, HV_BINOP_MULTIPLY, 0, m, &cBinop_fOYHPTLO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JkC245rz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CDm6ojOU, HV_BINOP_MULTIPLY, 0, m, &cBinop_CDm6ojOU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_voh0DVYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_lJqcGtf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wTdm39LM, 0, m, &cVar_wTdm39LM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JGGAE0jM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zi4k4GaL, 0, m, &cVar_zi4k4GaL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wGJ9BD03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o1LN3yZt, 1, m, &cIf_o1LN3yZt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ulMTKeSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MHyFEnnX, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WlQJ9z0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ulMTKeSv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wDv0b3M8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o1LN3yZt, 0, m, &cIf_o1LN3yZt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_lRGLvLu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_utPznxm1, HV_BINOP_DIVIDE, 0, m, &cBinop_utPznxm1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_tPeMEsUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FYS3r4Lt, HV_BINOP_DIVIDE, 1, m, &cBinop_FYS3r4Lt_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_utPznxm1, HV_BINOP_DIVIDE, 1, m, &cBinop_utPznxm1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_m1jZs6ho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vysyUoRU, HV_BINOP_DIVIDE, 0, m, &cBinop_vysyUoRU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_ELhAFuu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vysyUoRU, HV_BINOP_DIVIDE, 1, m, &cBinop_vysyUoRU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4dwRM0uu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FYS3r4Lt, HV_BINOP_DIVIDE, 0, m, &cBinop_FYS3r4Lt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xjm8Wiwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tPeMEsUg, 0, m, &cVar_tPeMEsUg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QVe8l13K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lRGLvLu9, 0, m, &cVar_lRGLvLu9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FYS3r4Lt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_m1jZs6ho_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_utPznxm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_ELhAFuu2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vysyUoRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_xQApIyjx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Pq4b1BVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_MBFfuMuT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mo7vKMtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_l8Mlrfyg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xQApIyjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_mo7vKMtr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_l8Mlrfyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_Pq4b1BVz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MBFfuMuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LXW4qNW2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_aJTdJHcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rB7UcZ9y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_JHf10oNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LqBLNZha_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_xJR8mGhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UXAtF6bY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_jhHq8pqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nvkqij62_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_rorHoEZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TY7VryHB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_pNUywqwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mx6EKpsr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_jPNv37sI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ke0TahRp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_dikKreHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dz3QcBoJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_s8SJFdbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4D32lnvy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_0dBHeCX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3OH6qrVe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_S0ukhbKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jcy5SdCm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Ft282RYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fJAjzzB1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_EMUUWwS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_tf6NcVEu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tf6NcVEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_D1ootq5S, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Qe0U1wSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KVWVChjz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_KVWVChjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Mw1iWzpZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_NKtslm0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IADr7QNw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_Jm2T0YLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_luPTYBYC_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_cq1Sb1Z0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Mw1iWzpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FxtHfXUg, m);
}

void Heavy_WSTD_FL3NGR::cMsg_IADr7QNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Jm2T0YLF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_luPTYBYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LT8n3izE, m);
}

void Heavy_WSTD_FL3NGR::cMsg_3HiUKKjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_v3YLLb2M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_v3YLLb2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_26Rbyc5T_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_5RjDjue7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zmH7NiHr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_tEHhQzWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_0Lrp7jLn_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_EgcvD9aH, m);
}

void Heavy_WSTD_FL3NGR::cBinop_26Rbyc5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_buM9bf80, m);
}

void Heavy_WSTD_FL3NGR::cMsg_zmH7NiHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tEHhQzWC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0Lrp7jLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GPo6zmSo, m);
}

void Heavy_WSTD_FL3NGR::cBinop_uuc1mQR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gWgJnSND_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gWgJnSND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_4t3eyJXr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Wglr9ZrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1Jg47bWP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_F3AWLksX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KzQmEanb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_4t3eyJXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Ze8uMWUC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ze8uMWUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pjPf67ru_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VuSfmAgA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VuSfmAgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yp7yaBVr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_pjPf67ru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_yEmr9Lp4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yEmr9Lp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_GiRCcV6w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Yp7yaBVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5h1CbPDD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5h1CbPDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_b1s9hrqP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GiRCcV6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_Wglr9ZrQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_b1s9hrqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_F3AWLksX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hDnzoLkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4rloQMK5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4rloQMK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8BglK0yJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_aCVFaGNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WNGvsBHv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_WNGvsBHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_TYnVz35S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_jHFnLTsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jHFnLTsi, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NVwZ0To1, 0, m, &cDelay_NVwZ0To1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jHFnLTsi, 0, m, &cDelay_jHFnLTsi_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ZPYbpKpP, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_NVwZ0To1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NVwZ0To1, m);
  cMsg_jvJRhno3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_blCWrmRE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ETYRzax1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_sQl3Wjgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QHGU746y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_btcsgDJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hzSLKM8O_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jHFnLTsi, 2, m, &cDelay_jHFnLTsi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H5vWyh11_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QHGU746y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_btcsgDJs, 0, m, &hTable_btcsgDJs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TYnVz35S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_sQl3Wjgp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_jvJRhno3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_btcsgDJs, 0, m, &hTable_btcsgDJs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_H5vWyh11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jHFnLTsi, 0, m, &cDelay_jHFnLTsi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_hzSLKM8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_NVwZ0To1, 2, m, &cDelay_NVwZ0To1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ETYRzax1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ZPYbpKpP, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_2y11YNxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_c7P90CBH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_c7P90CBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_JzkoXm91_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_hHIdJ2S8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hHIdJ2S8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nEsV4k2o, 0, m, &cDelay_nEsV4k2o_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hHIdJ2S8, 0, m, &cDelay_hHIdJ2S8_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_XZdFu1sM, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_nEsV4k2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nEsV4k2o, m);
  cMsg_vlIFbXeY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_A6V5WdoT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_1PhqO5UW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_NCqXO5UC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hawwi85j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_1LHXwIKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9WzT2bqg_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hHIdJ2S8, 2, m, &cDelay_hHIdJ2S8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NQfbigpT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Hawwi85j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_1LHXwIKz, 0, m, &hTable_1LHXwIKz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JzkoXm91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_NCqXO5UC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vlIFbXeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_1LHXwIKz, 0, m, &hTable_1LHXwIKz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_NQfbigpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hHIdJ2S8, 0, m, &cDelay_hHIdJ2S8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9WzT2bqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_nEsV4k2o, 2, m, &cDelay_nEsV4k2o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1PhqO5UW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_XZdFu1sM, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_zfVmVFmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GxlCdehj, HV_BINOP_MULTIPLY, 0, m, &cBinop_GxlCdehj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_q0ofFcb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tmjo74PU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_tmjo74PU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1SJpFHNk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_GxlCdehj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_lxC5t2fD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ONnUXw7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GxlCdehj, HV_BINOP_MULTIPLY, 1, m, &cBinop_GxlCdehj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1SJpFHNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ONnUXw7O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lxC5t2fD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_N1SZIQMT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_N1SZIQMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_3ZywfDKV_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_HO6v39qX, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3ZywfDKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ClamNtl1, m);
}

void Heavy_WSTD_FL3NGR::cVar_AQS4sBGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yoencgcj, HV_BINOP_MULTIPLY, 0, m, &cBinop_yoencgcj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mAKBo1eF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_57PSSMkR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_57PSSMkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1jvUqCIw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_yoencgcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_S3p0MutE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zOlNbN7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yoencgcj, HV_BINOP_MULTIPLY, 1, m, &cBinop_yoencgcj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1jvUqCIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zOlNbN7Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_S3p0MutE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_mG2lVOIs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mG2lVOIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IQBWXxhv_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WBHzi58W, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IQBWXxhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_l6jXU40P, m);
}

void Heavy_WSTD_FL3NGR::cMsg_8BglK0yJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gwpRBOmu, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_hQ9fUgD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_tOLKLjSB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Slu5LGcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_fT1wqXHS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_L9bnByhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_hQ9fUgD7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7QP3gTbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UO3e9jN1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UO3e9jN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D37NOsj3, HV_BINOP_MULTIPLY, 1, m, &cBinop_D37NOsj3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fT1wqXHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_7QP3gTbX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_D37NOsj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Sxwhtxsh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_tOLKLjSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D37NOsj3, HV_BINOP_MULTIPLY, 0, m, &cBinop_D37NOsj3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Sxwhtxsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z1PgpPDZ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_GnPsX911_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_VpUoUNYK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VpUoUNYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Slu5LGcq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L9bnByhI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_rbuz75ZC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_905wMUZ7, 0, m, &cSlice_905wMUZ7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IPYHouBz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_905wMUZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xxHgSq0D_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xxHgSq0D_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_GBTFmcPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xxHgSq0D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_xxHgSq0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lvZDvbX2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_IPYHouBz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_weuRot06, 0, m, &cSlice_weuRot06_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mW4MxtzO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_weuRot06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7U3GzMCN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7U3GzMCN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_gPEpFo2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7U3GzMCN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_7U3GzMCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rS45jPXq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_mW4MxtzO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_58rIIhOE, 0, m, &cSlice_58rIIhOE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bSGnM1PJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_58rIIhOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4elapx2h_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4elapx2h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_uC0ZZNV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4elapx2h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_4elapx2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hQ1oLN6f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_bSGnM1PJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PnZXdBMS, 0, m, &cSlice_PnZXdBMS_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_PnZXdBMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xm3jBsyY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xm3jBsyY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_j89tQxH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xm3jBsyY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_xm3jBsyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XRlEBBvX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_1Jg47bWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LUXc7hWl, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_KzQmEanb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mjv8jFQN, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_OgLtbl2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_9LRuA4JW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9LRuA4JW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_2LkW8BEZ, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_roP5A7KA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_I0e6zQiV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_I0e6zQiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_uwTXxBJI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_EvlQWUwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kc7FGukv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_Z9cjhRsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_BZDREBzD_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_vWICGudP, m);
}

void Heavy_WSTD_FL3NGR::cBinop_uwTXxBJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_V4k0Ozpf, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Kc7FGukv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Z9cjhRsW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BZDREBzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_gQ3w1p4k, m);
}

void Heavy_WSTD_FL3NGR::cMsg_hq5k9s6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RmdXx3qm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_RmdXx3qm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_CHeLbDho_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_6gTWELLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sa979F34_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_4NFZbx1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Pno01qDT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_SpWVnDqL, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CHeLbDho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Bx94GFU5, m);
}

void Heavy_WSTD_FL3NGR::cMsg_sa979F34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4NFZbx1G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Pno01qDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RUVkfB07, m);
}

void Heavy_WSTD_FL3NGR::cBinop_bgW2zsxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Z0D6v1Pv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Z0D6v1Pv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_JwDNBYrL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_93kU4pWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P7xgvgNm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_sJJcDXeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w90Vukqv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_JwDNBYrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9H8JB4O9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9H8JB4O9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MaDk2cmF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GG4MeiyV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MaDk2cmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KIrir9sl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GG4MeiyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MWcuVsvs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KIrir9sl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CKdRIfWK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MWcuVsvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kha68Bwo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kha68Bwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ykbvABmV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CKdRIfWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_93kU4pWR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ykbvABmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_sJJcDXeg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bS5pxtfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_1EzJaOzN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1EzJaOzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aPDfwWh2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_aB4HwTBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_z5izIWf2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_z5izIWf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_tygo1Tu1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_TlNt3356_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TlNt3356, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iWEc665I, 0, m, &cDelay_iWEc665I_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TlNt3356, 0, m, &cDelay_TlNt3356_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_gxlhdBQz, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_iWEc665I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iWEc665I, m);
  cMsg_dQ7VY4sz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_F9zfU1Cu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_OjMbQHJP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_bbA3CJ49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fqcf6i5r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_SmkOSjb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gdkur1EY_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TlNt3356, 2, m, &cDelay_TlNt3356_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_smxviUnB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fqcf6i5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_SmkOSjb2, 0, m, &hTable_SmkOSjb2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tygo1Tu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_bbA3CJ49_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_dQ7VY4sz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_SmkOSjb2, 0, m, &hTable_SmkOSjb2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_smxviUnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TlNt3356, 0, m, &cDelay_TlNt3356_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_gdkur1EY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_iWEc665I, 2, m, &cDelay_iWEc665I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OjMbQHJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_gxlhdBQz, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ssllZUL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rXjCyqAi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_rXjCyqAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_oxsmp6gO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_6myJgbSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6myJgbSs, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_F3KIyDTt, 0, m, &cDelay_F3KIyDTt_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6myJgbSs, 0, m, &cDelay_6myJgbSs_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_e9ftxHM1, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_F3KIyDTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_F3KIyDTt, m);
  cMsg_qz7Tbbzx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_6Y0tq1P0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_wjymYmfO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_U63xS2ZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lKjLSrmI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_SGyzbNGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aNzM3nzm_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6myJgbSs, 2, m, &cDelay_6myJgbSs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ceYolf6g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_lKjLSrmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_SGyzbNGb, 0, m, &hTable_SGyzbNGb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oxsmp6gO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_U63xS2ZE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qz7Tbbzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_SGyzbNGb, 0, m, &hTable_SGyzbNGb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ceYolf6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6myJgbSs, 0, m, &cDelay_6myJgbSs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_aNzM3nzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_F3KIyDTt, 2, m, &cDelay_F3KIyDTt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wjymYmfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_e9ftxHM1, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_5MrDUEVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lbv1V1HV, HV_BINOP_MULTIPLY, 0, m, &cBinop_lbv1V1HV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WQTBDeQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_S9ka97qg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_S9ka97qg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v5tQNKyl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_lbv1V1HV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_IfdSYfqe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2FvIpe9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lbv1V1HV, HV_BINOP_MULTIPLY, 1, m, &cBinop_lbv1V1HV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_v5tQNKyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2FvIpe9N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IfdSYfqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_YFt9WhKd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YFt9WhKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_GRmLCtKt_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_FLCaAQsU, m);
}

void Heavy_WSTD_FL3NGR::cBinop_GRmLCtKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hast3AJU, m);
}

void Heavy_WSTD_FL3NGR::cVar_q5gKkwvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XZXqq8vL, HV_BINOP_MULTIPLY, 0, m, &cBinop_XZXqq8vL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zoUOEe9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uLZtkXLa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_uLZtkXLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KSxAD3Ne_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XZXqq8vL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_7Wke3DQp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_B92y04rt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XZXqq8vL, HV_BINOP_MULTIPLY, 1, m, &cBinop_XZXqq8vL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KSxAD3Ne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_B92y04rt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7Wke3DQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_djrH8ctn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_djrH8ctn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_hRmKPplV_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qZgA9Itk, m);
}

void Heavy_WSTD_FL3NGR::cBinop_hRmKPplV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0aufd0Q0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_aPDfwWh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SImcAAti, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_GWqXWORh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_7WLHSntp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_SGyxTNpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_GWqXWORh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_DOgu3OMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_A9pJT12E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_s0Crhd14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_6li0pYPk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6li0pYPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rp4kcpJ4, HV_BINOP_MULTIPLY, 1, m, &cBinop_rp4kcpJ4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_A9pJT12E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_s0Crhd14_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rp4kcpJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fCKCl0Vu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_7WLHSntp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rp4kcpJ4, HV_BINOP_MULTIPLY, 0, m, &cBinop_rp4kcpJ4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fCKCl0Vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x8S6eF0t, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_2frOJ2bw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_TwkQZaRK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TwkQZaRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DOgu3OMT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SGyxTNpB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_mtdZ0IqR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dx6I7eHR, 0, m, &cSlice_dx6I7eHR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_q9WMVToT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_dx6I7eHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XyuP29u8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XyuP29u8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_bbD8Bbug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XyuP29u8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_XyuP29u8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_guCOpA1g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_q9WMVToT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yGAWwVim, 0, m, &cSlice_yGAWwVim_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fI0xGETM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_yGAWwVim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hlkcWoxk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hlkcWoxk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_EugowjRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hlkcWoxk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_hlkcWoxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_y58wnEqb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_fI0xGETM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_riiO3nj1, 0, m, &cSlice_riiO3nj1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EgduvXGF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_riiO3nj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VLpDDWk4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VLpDDWk4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_H39txYyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VLpDDWk4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_VLpDDWk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EFdCxz5V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_EgduvXGF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ABHePZtW, 0, m, &cSlice_ABHePZtW_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ABHePZtW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tMbWWIrV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tMbWWIrV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_HC6EJ5p8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tMbWWIrV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_tMbWWIrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DEyZ7dWE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_P7xgvgNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NAJnELOo, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_w90Vukqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vneUxki9, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_LkrpGLZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MFwJ7PvR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MFwJ7PvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_1XNwtBSY, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_P905eYAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZWHX1PlW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_ZWHX1PlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HTfyQsuq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_euUk76ob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NcY0QZee_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_USPPfufZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7RWfiTMt_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_cq4DDSsX, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HTfyQsuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rnvgcIFN, m);
}

void Heavy_WSTD_FL3NGR::cMsg_NcY0QZee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_USPPfufZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7RWfiTMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_svijPbNl, m);
}

void Heavy_WSTD_FL3NGR::cMsg_dhr4d0aR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kG4hMn8b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_kG4hMn8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xzCA9c1W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_LYr0XaCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_62DemrmJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_SWaVDn7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_8IjXXxfd_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ai75OyoS, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xzCA9c1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_oAo60du5, m);
}

void Heavy_WSTD_FL3NGR::cMsg_62DemrmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SWaVDn7a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8IjXXxfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RpRyvhFl, m);
}

void Heavy_WSTD_FL3NGR::cBinop_G5ih8ULW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8rEXz73R_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8rEXz73R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_PpoVexfu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_F8Gn23IG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_goYI1AsH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_QJknmaDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xyEG6zKa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_PpoVexfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1D45SEHr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1D45SEHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ATlHkoKZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WjhleRlk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_WjhleRlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QZMcWWZa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_ATlHkoKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qJMrkv60_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qJMrkv60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EPnN16pF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QZMcWWZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nAxVn5I7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nAxVn5I7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_q88ksP9w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EPnN16pF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_F8Gn23IG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_q88ksP9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_QJknmaDh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_P7eXVRlO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_vAdpuMZU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vAdpuMZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B2ERZLSg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ZE44DlYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KRR1Oe40_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_KRR1Oe40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_zXlwqtSC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_8tKa9Py0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8tKa9Py0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ug4aCTwv, 0, m, &cDelay_ug4aCTwv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8tKa9Py0, 0, m, &cDelay_8tKa9Py0_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_aFSBJYhh, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_ug4aCTwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ug4aCTwv, m);
  cMsg_Hwo48v1q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_cmu5t2gR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_lV6Af4MU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_0NZbnG6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zzHmG2D6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_sU0MT3tE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WWM3EYuQ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8tKa9Py0, 2, m, &cDelay_8tKa9Py0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yMEoSR9C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zzHmG2D6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_sU0MT3tE, 0, m, &hTable_sU0MT3tE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zXlwqtSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_0NZbnG6h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Hwo48v1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_sU0MT3tE, 0, m, &hTable_sU0MT3tE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yMEoSR9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8tKa9Py0, 0, m, &cDelay_8tKa9Py0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WWM3EYuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_ug4aCTwv, 2, m, &cDelay_ug4aCTwv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_lV6Af4MU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_aFSBJYhh, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_yoswayLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lDCb0Xjx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_lDCb0Xjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_dSNYd27H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_F14KMy8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_F14KMy8x, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JPcV2Zxn, 0, m, &cDelay_JPcV2Zxn_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_F14KMy8x, 0, m, &cDelay_F14KMy8x_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4YyZ2uvz, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_JPcV2Zxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JPcV2Zxn, m);
  cMsg_8Y9aZFxe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_WQAbnMKt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_6C03Hpgn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_AgyKRKHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Atncul7J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_mOUF5EB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LkbJZQjc_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_F14KMy8x, 2, m, &cDelay_F14KMy8x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IIQsWs46_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Atncul7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_mOUF5EB2, 0, m, &hTable_mOUF5EB2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dSNYd27H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_AgyKRKHa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8Y9aZFxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_mOUF5EB2, 0, m, &hTable_mOUF5EB2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IIQsWs46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_F14KMy8x, 0, m, &cDelay_F14KMy8x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_LkbJZQjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_JPcV2Zxn, 2, m, &cDelay_JPcV2Zxn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6C03Hpgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4YyZ2uvz, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_rFGo7YX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ndOVxev3, HV_BINOP_MULTIPLY, 0, m, &cBinop_ndOVxev3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_RD7w5nKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_f3mLwmeg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_f3mLwmeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6q54xxay_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ndOVxev3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_YPMDyvjp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZlSwBkPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ndOVxev3, HV_BINOP_MULTIPLY, 1, m, &cBinop_ndOVxev3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6q54xxay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZlSwBkPD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YPMDyvjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_T9RE0WSt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_T9RE0WSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_QO2sv1KI_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lvwdbGwn, m);
}

void Heavy_WSTD_FL3NGR::cBinop_QO2sv1KI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ex2YCaeE, m);
}

void Heavy_WSTD_FL3NGR::cVar_ylF1ZQZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZxhxzDDH, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZxhxzDDH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mrpryg51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_X7rYAZt9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_X7rYAZt9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_StWWpt1s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ZxhxzDDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Cp5r5qqK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hrsB8pfL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZxhxzDDH, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZxhxzDDH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_StWWpt1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hrsB8pfL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Cp5r5qqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_eYAlqkbP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eYAlqkbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_SxMc5iL8_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_2qclSnF4, m);
}

void Heavy_WSTD_FL3NGR::cBinop_SxMc5iL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ZsyuYOAV, m);
}

void Heavy_WSTD_FL3NGR::cMsg_B2ERZLSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3PYDq4Ni, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_3UEE9XTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_EaJTveNj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IYEbsjDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_irm64Fn0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FvTfgHDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_3UEE9XTw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UWp9bhAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_REf74E7W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_REf74E7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R3AQg9U6, HV_BINOP_MULTIPLY, 1, m, &cBinop_R3AQg9U6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_irm64Fn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_UWp9bhAx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_R3AQg9U6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YPXKDN3a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_EaJTveNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R3AQg9U6, HV_BINOP_MULTIPLY, 0, m, &cBinop_R3AQg9U6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YPXKDN3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c1wcgcxq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_NB16verS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_PXKuPtNB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PXKuPtNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IYEbsjDz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FvTfgHDl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_7zMntMfw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CJc6nP8t, 0, m, &cSlice_CJc6nP8t_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xAjFfAvw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_CJc6nP8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5Nd8cgfu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5Nd8cgfu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_cBAMqUra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5Nd8cgfu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_5Nd8cgfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UrraDKZX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_xAjFfAvw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qcFSegAO, 0, m, &cSlice_qcFSegAO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VDauf02C_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_qcFSegAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7aCtrMAj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7aCtrMAj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_xxtyXYjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7aCtrMAj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_7aCtrMAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xdkLyO0V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_VDauf02C_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uc3SNbKx, 0, m, &cSlice_uc3SNbKx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hjgLEE6p_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_uc3SNbKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yrOQGvK1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yrOQGvK1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_3DkVsQK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yrOQGvK1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_yrOQGvK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uVi53yKc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_hjgLEE6p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4fVSgZGA, 0, m, &cSlice_4fVSgZGA_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_4fVSgZGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8whUyued_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8whUyued_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_0ctHWm6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8whUyued_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_8whUyued_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uALiMTpq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_goYI1AsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tNOclUr5, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_xyEG6zKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s9WROZuE, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_vu1gvfFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_LUZUPBSA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qg2dFEBP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_fDVCFRWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_LUZUPBSA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qg2dFEBP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_EtvZdqbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_LUZUPBSA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qg2dFEBP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_mWIMEMnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_LUZUPBSA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qg2dFEBP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LXW4qNW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_LUZUPBSA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_qg2dFEBP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_yZjScWJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_HXUEig5A, 0, m, &cVar_HXUEig5A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_x1PXuPGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_o8A9tmbz, 0, m, &cVar_o8A9tmbz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_x9z1Te0w, 0, m, &cVar_x9z1Te0w_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XqxJaFF0, 0, m, &cVar_XqxJaFF0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Nvkqij62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_rbuz75ZC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_rB7UcZ9y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_rbuz75ZC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LqBLNZha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_rbuz75ZC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_UXAtF6bY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_rbuz75ZC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_dEA6g6ol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jhHq8pqp, 0, m, &cVar_jhHq8pqp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eRkxBI1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aJTdJHcw, 0, m, &cVar_aJTdJHcw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wYswATiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xJR8mGhG, 0, m, &cVar_xJR8mGhG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_dz3QcBoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mtdZ0IqR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_TY7VryHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mtdZ0IqR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Mx6EKpsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mtdZ0IqR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ke0TahRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mtdZ0IqR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_mq584DJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dikKreHj, 0, m, &cVar_dikKreHj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IUl2ZEs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rorHoEZ0, 0, m, &cVar_rorHoEZ0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PekaGDaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jPNv37sI, 0, m, &cVar_jPNv37sI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fJAjzzB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7zMntMfw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_4D32lnvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7zMntMfw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_3OH6qrVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7zMntMfw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_jcy5SdCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7zMntMfw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_ycQc6P1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ft282RYe, 0, m, &cVar_Ft282RYe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_m6uR4Adq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_s8SJFdbl, 0, m, &cVar_s8SJFdbl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_i1KK19eW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S0ukhbKo, 0, m, &cVar_S0ukhbKo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_rm5NRlSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o8A9tmbz, 0, m, &cVar_o8A9tmbz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_GSNrDMgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x9z1Te0w, 0, m, &cVar_x9z1Te0w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_zYFyXbRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XqxJaFF0, 0, m, &cVar_XqxJaFF0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_os3hwDxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nh9RBBpq, 0, m, &cVar_nh9RBBpq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_G4GxBo08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M714wBAJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xcXxz3QP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_J4po4KVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s0DIDd1v_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3tG1XDZB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CuBM2X3U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_vrZWLVKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6OffAc7S_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2kxriEHA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vIv4zZtq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_XZ7tQsS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f4Eof832_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8qLAzEzh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Lnp0TC5d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_MTQsxuQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lHkydcA9_sendMessage(_c, 0, m);
  cMsg_AR57xBd7_sendMessage(_c, 0, m);
  cMsg_S3B6uoww_sendMessage(_c, 0, m);
  cMsg_4gUvuK59_sendMessage(_c, 0, m);
  cMsg_1cCmbae5_sendMessage(_c, 0, m);
  cMsg_cBsr17gl_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_pk1hMEiu, 0, m, &cVar_pk1hMEiu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nh9RBBpq, 0, m, &cVar_nh9RBBpq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WxTn34EO, 0, m, &cVar_WxTn34EO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iapsyl1a, 0, m, &cVar_iapsyl1a_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_R3lVz23F, 0, m, &cVar_R3lVz23F_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SojdpE5A, 0, m, &cVar_SojdpE5A_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_t8xCIRtH, 0, m, &cVar_t8xCIRtH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wNN29RX1, 0, m, &cVar_wNN29RX1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hYfdJxDv, 0, m, &cVar_hYfdJxDv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ArzTSclC, 0, m, &cVar_ArzTSclC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZZ0PPLjI, 0, m, &cVar_ZZ0PPLjI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ldne6noG, 0, m, &cVar_Ldne6noG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yWd8Wncu, 0, m, &cVar_yWd8Wncu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fieuYC5z, 0, m, &cVar_fieuYC5z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JUHR9hFS, 0, m, &cVar_JUHR9hFS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7MsDGqAr, 0, m, &cVar_7MsDGqAr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vkFKW2wP, 0, m, &cVar_vkFKW2wP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hOKxTDXL, 0, m, &cVar_hOKxTDXL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_z8RveAy7, 0, m, &cVar_z8RveAy7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yc9pLqa9, 0, m, &cVar_yc9pLqa9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AITo1J5P, 0, m, &cVar_AITo1J5P_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aLWTbw3l, 0, m, &cVar_aLWTbw3l_sendMessage);
  cMsg_q0ofFcb9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zfVmVFmo, 0, m, &cVar_zfVmVFmo_sendMessage);
  cMsg_mAKBo1eF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_AQS4sBGN, 0, m, &cVar_AQS4sBGN_sendMessage);
  cMsg_WQTBDeQ1_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5MrDUEVi, 0, m, &cVar_5MrDUEVi_sendMessage);
  cMsg_zoUOEe9v_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_q5gKkwvt, 0, m, &cVar_q5gKkwvt_sendMessage);
  cMsg_RD7w5nKF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_rFGo7YX9, 0, m, &cVar_rFGo7YX9_sendMessage);
  cMsg_mrpryg51_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ylF1ZQZn, 0, m, &cVar_ylF1ZQZn_sendMessage);
  cMsg_aCVFaGNY_sendMessage(_c, 0, m);
  cMsg_2y11YNxC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_GBTFmcPZ, 0, m, &cVar_GBTFmcPZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gPEpFo2w, 0, m, &cVar_gPEpFo2w_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uC0ZZNV9, 0, m, &cVar_uC0ZZNV9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_j89tQxH8, 0, m, &cVar_j89tQxH8_sendMessage);
  cMsg_aB4HwTBy_sendMessage(_c, 0, m);
  cMsg_ssllZUL7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bbD8Bbug, 0, m, &cVar_bbD8Bbug_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EugowjRN, 0, m, &cVar_EugowjRN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H39txYyn, 0, m, &cVar_H39txYyn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HC6EJ5p8, 0, m, &cVar_HC6EJ5p8_sendMessage);
  cMsg_ZE44DlYA_sendMessage(_c, 0, m);
  cMsg_yoswayLH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cBAMqUra, 0, m, &cVar_cBAMqUra_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xxtyXYjO, 0, m, &cVar_xxtyXYjO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3DkVsQK5, 0, m, &cVar_3DkVsQK5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0ctHWm6J, 0, m, &cVar_0ctHWm6J_sendMessage);
  cMsg_x1PXuPGF_sendMessage(_c, 0, m);
  cMsg_yZjScWJa_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NKtslm0A, 0, m, &cVar_NKtslm0A_sendMessage);
  cMsg_Qe0U1wSV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5RjDjue7, 0, m, &cVar_5RjDjue7_sendMessage);
  cMsg_3HiUKKjZ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_EvlQWUwa, 0, m, &cVar_EvlQWUwa_sendMessage);
  cMsg_roP5A7KA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_6gTWELLO, 0, m, &cVar_6gTWELLO_sendMessage);
  cMsg_hq5k9s6B_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_euUk76ob, 0, m, &cVar_euUk76ob_sendMessage);
  cMsg_P905eYAT_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_LYr0XaCz, 0, m, &cVar_LYr0XaCz_sendMessage);
  cMsg_dhr4d0aR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_N8dkH6yb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rf9ikTkF, HV_BINOP_MULTIPLY, 0, m, &cBinop_Rf9ikTkF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_rOK7pRTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_WNHUwfPn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_vQMc1MJH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CMqTMnq9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_VftjdrLW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_p9JE6vZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_I6q0wFG2_sendMessage);
  cMsg_YR8nR7sN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_HVbFzLGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v8MEoQ7x, HV_BINOP_MULTIPLY, 0, m, &cBinop_v8MEoQ7x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bHRGMDuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_HlXTmeF3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_V2JQc5JB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y8xrknEB, HV_BINOP_MULTIPLY, 1, m, &cBinop_y8xrknEB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Bktxexqr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bnfk6lN3_sendMessage);
  cMsg_gMEKQz1d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_Ue7FvZci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gSfj5WmF, HV_BINOP_MULTIPLY, 0, m, &cBinop_gSfj5WmF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_xFJNhQjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9huyTX7o_sendMessage(_c, 0, m);
  cMsg_pxtoble4_sendMessage(_c, 0, m);
  cMsg_0Xv7pqTC_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_mrKZgaGS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_XVGfe1AN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9zYZ1Z5J_sendMessage);
  cMsg_KVPTeWQO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_4L266jDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R3lVz23F, 0, m, &cVar_R3lVz23F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_gAen2o06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3AOaAICg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nmcqnlBq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ms0WeLI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KEvi7Ao8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hBEz3iEN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4cjNPXuH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_9cNvQizn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vZDsGjeq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zVUHEhjX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QSV9ycvr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ak3XjFAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1oKBwYMB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xxo6MXfs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iCkc3JpQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_M5FOneZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5mhj3ZpT, HV_BINOP_MULTIPLY, 0, m, &cBinop_5mhj3ZpT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ckTUfXQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bGIeJpAV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pRWdhTUY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_AqpMzNYl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_9PwaMMLE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_eN3nUNEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9XutMVjE_sendMessage);
  cMsg_ewecwcwk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_zxjOqzLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zAiObrVB, HV_BINOP_MULTIPLY, 0, m, &cBinop_zAiObrVB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_a7jwNwGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ETb3cZtv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Ny7fLofM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7NbbRn1T, HV_BINOP_MULTIPLY, 1, m, &cBinop_7NbbRn1T_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_KyiXzyXQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7mlgaU9m_sendMessage);
  cMsg_CYkDgfCD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_KQFa3H9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WUlfxyiA, HV_BINOP_MULTIPLY, 0, m, &cBinop_WUlfxyiA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_yLanmWNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XgYTWdQA_sendMessage(_c, 0, m);
  cMsg_PuQopHxd_sendMessage(_c, 0, m);
  cMsg_CYybo9VA_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_WqjpcULp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_SUPC5S9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HegYJ5Yk_sendMessage);
  cMsg_uoUzq7vc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_zq46d6jN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HXUEig5A, 0, m, &cVar_HXUEig5A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_f6kTBDXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_dEA6g6ol_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_aUytVHlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_eRkxBI1f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_RKzbNbz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JHf10oNk, 0, m, &cVar_JHf10oNk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Rxllfl5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_wYswATiI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_YHPlyuxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_mq584DJm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_huyI4hGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_IUl2ZEs9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bpnFOGAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pNUywqwc, 0, m, &cVar_pNUywqwc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_2YL6THoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_PekaGDaD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_UaLrftUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ycQc6P1Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_SAc6hFgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_m6uR4Adq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_9DOeqE5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0dBHeCX0, 0, m, &cVar_0dBHeCX0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_zAzGXtl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_i1KK19eW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_hQ1oLN6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_EMUUWwS3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_rS45jPXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_GnPsX911_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_XRlEBBvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_uuc1mQR0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_lvZDvbX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hDnzoLkC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_EFdCxz5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_OgLtbl2s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_y58wnEqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_2frOJ2bw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_DEyZ7dWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_bgW2zsxx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_guCOpA1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_bS5pxtfh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_uVi53yKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_LkrpGLZC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_xdkLyO0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_NB16verS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_uALiMTpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_G5ih8ULW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_UrraDKZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_P7eXVRlO_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_1Gx7Y2HF, VOf(Bf0));
    __hv_line_f(&sLine_ZYCXxeBS, VOf(Bf1));
    __hv_line_f(&sLine_Mh7UIyif, VOf(Bf2));
    __hv_line_f(&sLine_zrZ8Zn9V, VOf(Bf3));
    __hv_line_f(&sLine_8FvoQI2x, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_KmPgclus, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_2yV6Qlef, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_BNTXFjSi, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_tUFVb7Fh, VOf(Bf1));
    __hv_line_f(&sLine_M0Qx4cDN, VOf(Bf0));
    __hv_line_f(&sLine_ig5Dd3Oq, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_aBFRnTkX, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_7s7XzUZ3, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_B2RVniFC, VOf(Bf5));
    __hv_line_f(&sLine_UMedoi9s, VOf(Bf1));
    __hv_line_f(&sLine_UlGSEZ28, VOf(Bf2));
    __hv_line_f(&sLine_Zj57gEy9, VOf(Bf4));
    __hv_line_f(&sLine_qEEzkQ9W, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_XqXqdMxL, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_3E1bPcDT, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_70jxgnyg, VOf(Bf6));
    __hv_line_f(&sLine_fMHKhqQY, VOf(Bf2));
    __hv_line_f(&sLine_o3j1ELj8, VOf(Bf1));
    __hv_line_f(&sLine_h0GpShuZ, VOf(Bf5));
    __hv_line_f(&sLine_T4A5wP6B, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_6oriTvMc, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_QUTf2Unh, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_YkAO5F8i, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_8i2nqTKK, VOf(Bf2));
    __hv_line_f(&sLine_qEk3Po23, VOf(Bf6));
    __hv_line_f(&sLine_qjpZEpFl, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_NqkyL5lW, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_MHyFEnnX, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_JU0cfcXC, VOf(Bf8));
    __hv_line_f(&sLine_zXwZug79, VOf(Bf2));
    __hv_line_f(&sLine_ubcys9bZ, VOf(Bf1));
    __hv_line_f(&sLine_hy2GDL01, VOf(Bf7));
    __hv_line_f(&sLine_F2Yy0nTJ, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_uUDmcPkg, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_wo1naiXK, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_mjv8jFQN, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_D1ootq5S, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_gwpRBOmu, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_HO6v39qX, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_ClamNtl1, VOf(Bf8));
    __hv_rpole_f(&sRPole_LMkg5HzG, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_WBHzi58W, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_l6jXU40P, VOf(Bf10));
    __hv_rpole_f(&sRPole_u6YuH2zn, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_qT2NwMo2, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_FxtHfXUg, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_LT8n3izE, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_cq1Sb1Z0, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_hNPzL4D0, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_UGuJWXUU, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_LUXc7hWl, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_Ra0D9seO, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_buM9bf80, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_GPo6zmSo, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_EgcvD9aH, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_YCfT3UuN, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_o65nHdTh, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_Z1PgpPDZ, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_ZPYbpKpP, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_XZdFu1sM, VIf(Bf3));
    __hv_varwrite_f(&sVarf_VMhBiQK0, VIf(Bf11));
    __hv_line_f(&sLine_vneUxki9, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_2LkW8BEZ, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_SImcAAti, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_FLCaAQsU, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_hast3AJU, VOf(Bf10));
    __hv_rpole_f(&sRPole_NSjmtnqk, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_qZgA9Itk, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_0aufd0Q0, VOf(Bf5));
    __hv_rpole_f(&sRPole_9HX7KN0d, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_kzXiEHwA, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_V4k0Ozpf, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_gQ3w1p4k, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_vWICGudP, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_CE2HBtuj, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_PSCMOilS, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_NAJnELOo, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_Rz7lE6Dn, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_Bx94GFU5, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_RUVkfB07, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_SpWVnDqL, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_doxjHEXY, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_7hbxj1t6, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_x8S6eF0t, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_gxlhdBQz, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_e9ftxHM1, VIf(Bf0));
    __hv_varwrite_f(&sVarf_OCT6OsQ2, VIf(Bf8));
    __hv_line_f(&sLine_s9WROZuE, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_1XNwtBSY, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_3PYDq4Ni, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_lvwdbGwn, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_Ex2YCaeE, VOf(Bf5));
    __hv_rpole_f(&sRPole_ZrcrR4E5, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_2qclSnF4, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_ZsyuYOAV, VOf(Bf6));
    __hv_rpole_f(&sRPole_oMmv15Hr, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_xFElLJUa, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_rnvgcIFN, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_svijPbNl, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_cq4DDSsX, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_r6LDJnSj, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_USBpd2Pd, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_tNOclUr5, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_bgLE2dj0, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_oAo60du5, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_RpRyvhFl, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_ai75OyoS, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_qKE1QuFC, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_2u5S25OV, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_c1wcgcxq, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_aFSBJYhh, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_4YyZ2uvz, VIf(Bf4));
    __hv_varwrite_f(&sVarf_cwNJp3sv, VIf(Bf10));
    __hv_varwrite_f(&sVarf_bCCW3Fvm, VIf(Bf2));
    __hv_varwrite_f(&sVarf_Yuw0dXBd, VIf(Bf9));
    __hv_varwrite_f(&sVarf_FVs3ikSS, VIf(Bf11));
    __hv_varread_f(&sVarf_VMhBiQK0, VOf(Bf11));
    __hv_varread_f(&sVarf_OCT6OsQ2, VOf(Bf9));
    __hv_varread_f(&sVarf_cwNJp3sv, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_bCCW3Fvm, VOf(Bf2));
    __hv_varread_f(&sVarf_Yuw0dXBd, VOf(Bf11));
    __hv_varread_f(&sVarf_FVs3ikSS, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
